@@ -279,6 +279,16 @@ class fillVars(varsShare):
         else:
             return ""
 
+    def get_hr_cdrom_set(self):
+        """Cdrom variable"""
+        if os.path.exists('/sys/block/sr0'):
+            textLines = self._runos("udevadm info --query=all --name=/dev/dvdrw")
+            if not textLines is False:
+                for line in textLines:
+                    if "ID_CDROM=1" in line:
+                        return "on"
+        return "off"
+
     def get_hr_virtual(self):
         """Virtual machine name (virtualbox, vmware, qemu)"""
         pciLines = self._runos("/usr/sbin/lspci")
